searchData={"items":[{"type":"module","doc":"LiveDashboard provides real-time performance monitoring and debugging tools for Phoenix developers. It provides the following modules:\n\n- Home - See general information about the system\n\n- OS Data - See general information about OS, such as CPU, Memory and Disk usage\n\n- Metrics - See how your application performs under different conditions by visualizing [`:telemetry`](https://hexdocs.pm/telemetry) events with real-time charts\n\n- Request logging - See everything that was logged for certain requests\n\n- Applications - See, filter, and search applications in the current node and view their processes in a supervision tree\n\n- Processes - See, filter, and search processes in the current node\n\n- Ports - See, filter, and search ports (responsible for I/O) in the current node\n\n- Sockets - See, filter, and search sockets (responsible for tcp/udp) in the current node\n\n- ETS - See, filter, and search ETS tables (in-memory storage) in the current node\n\n- Ecto Stats - Shows index, table, and general usage about the underlying Ecto Repo storage\n\nThe dashboard also works across nodes. If your nodes are connected via Distributed Erlang, then you can access information from node B while accessing the dashboard on node A.\n\n![screenshot](https://github.com/phoenixframework/phoenix_live_dashboard/raw/main/screenshot.png)","title":"Phoenix.LiveDashboard","ref":"Phoenix.LiveDashboard.html"},{"type":"module","doc":"The LiveDashboard is built on top of LiveView. Both LiveView and LiveDashboard ship by default as part of Phoenix. But if you skipped them, you can LiveDashboard in three steps:\n\n1. Add the `phoenix_live_dashboard` dependency\n2. Configure LiveView\n3. Add dashboard access","title":"Installation - Phoenix.LiveDashboard","ref":"Phoenix.LiveDashboard.html#module-installation"},{"type":"module","doc":"Add the following to your `mix.exs` and run `mix deps.get`:\n\n```elixir\ndef deps do\n  [\n    {:phoenix_live_dashboard, \"~> 0.7\"}\n  ]\nend\n```","title":"1. Add the `phoenix_live_dashboard` dependency - Phoenix.LiveDashboard","ref":"Phoenix.LiveDashboard.html#module-1-add-the-phoenix_live_dashboard-dependency"},{"type":"module","doc":"First, update your endpoint's configuration to include a signing salt:\n\n```elixir\n# config/config.exs\nconfig :my_app, MyAppWeb.Endpoint,\n  live_view: [signing_salt: \"SECRET_SALT\"]\n```\n\nThen add the `Phoenix.LiveView.Socket` declaration to your endpoint:\n\n```elixir\nsocket \"/live\", Phoenix.LiveView.Socket\n```\n\nAnd you are good to go!","title":"2. Configure LiveView - Phoenix.LiveDashboard","ref":"Phoenix.LiveDashboard.html#module-2-configure-liveview"},{"type":"module","doc":"Once installed, update your router's configuration to forward requests to a LiveDashboard with a unique `name` of your choosing:\n\n```elixir\n# lib/my_app_web/router.ex\nuse MyAppWeb, :router\nimport Phoenix.LiveDashboard.Router\n\n...\n\nif Mix.env() == :dev do\n  scope \"/\" do\n    pipe_through :browser\n    live_dashboard \"/dashboard\"\n  end\nend\n```\n\nThis is all. Run `mix phx.server` and access the \"/dashboard\" to configure the necessary modules.","title":"3. Add dashboard access for development-only usage - Phoenix.LiveDashboard","ref":"Phoenix.LiveDashboard.html#module-3-add-dashboard-access-for-development-only-usage"},{"type":"module","doc":"If you want to use the LiveDashboard in production, you should put authentication in front of it. For example, if you use `mix phx.gen.auth` to generate an Admin resource, you could use the following code:\n\n```elixir\n# lib/my_app_web/router.ex\nuse MyAppWeb, :router\nimport Phoenix.LiveDashboard.Router\n\n...\n\npipeline :admins_only do\n  plug :fetch_current_admin\n  plug :require_authenticated_admin\nend\n\nscope \"/\" do\n  pipe_through [:browser, :admins_only]\n  live_dashboard \"/dashboard\"\nend\n```\n\nIf you'd rather have some quick and dirty HTTP Authentication, the following code can be used as a starting point:\n\n```elixir\n# lib/my_app_web/router.ex\nuse MyAppWeb, :router\nimport Phoenix.LiveDashboard.Router\n\n...\n\npipeline :admins_only do\n  plug :admin_basic_auth\nend\n\nscope \"/\" do\n  pipe_through [:browser, :admins_only]\n  live_dashboard \"/dashboard\"\nend\n\ndefp admin_basic_auth(conn, _opts) do\n  username = System.fetch_env!(\"AUTH_USERNAME\")\n  password = System.fetch_env!(\"AUTH_PASSWORD\")\n  Plug.BasicAuth.basic_auth(conn, username: username, password: password)\nend\n```\n\nIf you are running your application behind a proxy or a webserver, you also have to make sure they are configured for allowing WebSocket upgrades. For example, [here is an article](https://web.archive.org/web/20171104012240/https://dennisreimann.de/articles/phoenix-nginx-config.html) on how to configure Nginx with Phoenix and WebSockets.","title":"Extra: Add dashboard access on all environments (including production) - Phoenix.LiveDashboard","ref":"Phoenix.LiveDashboard.html#module-extra-add-dashboard-access-on-all-environments-including-production"},{"type":"function","doc":"Extracts a datapoint for the given metric.\n\nReceives a `Telemetry.Metric` as `metric`, alongside the `measurements`\nand `metadata` from the Telemetry event, and an optional `time` and\nreturns an extracted datapoint or `nil` if the event is not part of\nthe metric.\n\nNote that it is expected that the event name was already validated as\npart of the metric.","title":"Phoenix.LiveDashboard.extract_datapoint_for_metric/4","ref":"Phoenix.LiveDashboard.html#extract_datapoint_for_metric/4"},{"type":"behaviour","doc":"Page builder is the default mechanism for building custom dashboard pages.\n\nEach dashboard page is a LiveView with additional callbacks for\ncustomizing the menu appearance and the automatic refresh.\n\nA simple and straight-forward example of a custom page is the\n`Phoenix.LiveDashboard.EtsPage` that ships with the dashboard:\n\n    defmodule Phoenix.LiveDashboard.EtsPage do\n      @moduledoc false\n      use Phoenix.LiveDashboard.PageBuilder\n\n      @impl true\n      def menu_link(_, _) do\n        {:ok, \"ETS\"}\n      end\n\n      @impl true\n      def render(assigns) do\n        ~H\"\"\"\n        <.live_table\n          id=\"ets-table\"\n          dom_id=\"ets-table\"\n          page={@page}\n          title=\"ETS\"\n          row_fetcher={&fetch_ets/2}\n          row_attrs={&row_attrs/1}\n          rows_name=\"tables\"\n        >\n          <:col field={:name} header=\"Name or module\" />\n          <:col field={:protection} />\n          <:col field={:type} />\n          <:col field={:size} text_align=\"right\" sortable={:desc} />\n          <:col field={:memory} text_align=\"right\" sortable={:desc} :let={ets}>\n            <%= format_words(ets[:memory]) %>\n          </:col>\n          <:col field={:owner} :let={ets} >\n            <%= encode_pid(ets[:owner]) %>\n          </:col>\n        </.live_table>\n        \"\"\"\n      end\n\n      defp fetch_ets(params, node) do\n        %{search: search, sort_by: sort_by, sort_dir: sort_dir, limit: limit} = params\n\n        # Here goes the code that goes through all ETS tables, searches\n        # (if not nil), sorts, and limits them.\n        #\n        # It must return a tuple where the first element is list with\n        # the current entries (up to limit) and an integer with the\n        # total amount of entries.\n        # ...\n      end\n\n      defp row_attrs(table) do\n        [\n          {\"phx-click\", \"show_info\"},\n          {\"phx-value-info\", encode_ets(table[:id])},\n          {\"phx-page-loading\", true}\n        ]\n      end\n    end\n\nOnce a page is defined, it must be declared in your `live_dashboard`\nroute as follows:\n\n    live_dashboard \"/dashboard\",\n      additional_pages: [\n        route_name: MyAppWeb.MyCustomPage\n      ]\n\nOr alternatively:\n\n    live_dashboard \"/dashboard\",\n      additional_pages: [\n        route_name: {MyAppWeb.MyCustomPage, some_option: ...}\n      ]\n\nThe second argument of the tuple will be given to the `c:init/1`\ncallback. If not tuple is given, `c:init/1` will receive an empty\nlist.","title":"Phoenix.LiveDashboard.PageBuilder","ref":"Phoenix.LiveDashboard.PageBuilder.html"},{"type":"behaviour","doc":"The following options can be given when using the `PageBuilder` module:\n\n* `refresher?` - Boolean to enable or disable the automatic refresh in the page.","title":"Options for the use macro - Phoenix.LiveDashboard.PageBuilder","ref":"Phoenix.LiveDashboard.PageBuilder.html#module-options-for-the-use-macro"},{"type":"behaviour","doc":"A page can return any valid HEEx template in the `render/1` callback,\nand it can use the components listed with this page too.\n\nWe currently support `card/1`, `fields_card/1`, `row/1`,\n`shared_usage_card/1`, and `usage_card/1`;\nand the live components `live_layered_graph/1`, `live_nav_bar/1`,\nand `live_table/1`.","title":"Components - Phoenix.LiveDashboard.PageBuilder","ref":"Phoenix.LiveDashboard.PageBuilder.html#module-components"},{"type":"behaviour","doc":"Some helpers are available for page building. The supported\nhelpers are: `live_dashboard_path/2`, `live_dashboard_path/3`,\n`encode_app/1`, `encode_ets/1`, `encode_pid/1`, `encode_port/1`,\nand `encode_socket/1`.","title":"Helpers - Phoenix.LiveDashboard.PageBuilder","ref":"Phoenix.LiveDashboard.PageBuilder.html#module-helpers"},{"type":"behaviour","doc":"If your page needs to register custom hooks, you can use the `register_after_opening_head_tag/2`\nfunction. Because the hooks need to be available on the dead render in the layout, before the\nLiveView's LiveSocket is configured, your need to do this inside an `on_mount` hook:\n\n```elixir\ndefmodule MyAppWeb.MyLiveDashboardHooks do\n  import Phoenix.LiveView\n  import Phoenix.Component\n\n  alias Phoenix.LiveDashboard.PageBuilder\n\n  def on_mount(:default, _params, _session, socket) do\n    {:cont, PageBuilder.register_after_opening_head_tag(socket, &after_opening_head_tag/1)}\n  end\n\n  defp after_opening_head_tag(assigns) do\n    ~H\"\"\"\n     \n      window.LiveDashboard.registerCustomHooks({\n        MyHook: {\n          mounted() {\n            // do something\n          }\n        }\n      })\n     \n    \"\"\"\n  end\nend\n\ndefmodule MyAppWeb.MyCustomPage do\n  ...\nend\n```\n\nAnd then add it to the list of `on_mount` hooks in the `live_dashboard` router configuration:\n\n```elixir\nlive_dashboard \"/dashboard\",\n  additional_pages: [\n    route_name: MyAppWeb.MyCustomPage\n  ],\n  on_mount: [\n    MyAppWeb.MyLiveDashboardHooks\n  ]\n```\n\nThe LiveDashboard provides a function `window.LiveDashboard.registerCustomHooks({ ... })` that you can call\nwith an object of hook declarations.\n\nNote that in order to use external libraries, you will either need to include them from\na CDN, or bundle them yourself and include them from your app's static paths.\n\n> #### A note on CSPs and libraries {: .info}\n>\n> Phoenix LiveDashboard supports CSP nonces for its own assets, configurable using the\n> `Phoenix.LiveDashboard.Router.live_dashboard/2` macro by setting the `:csp_nonce_assign_key`\n> option. If you are building a library, ensure that you render those CSP nonces on any scripts,\n> styles or images of your page. The nonces are passed to your custom page under the `:csp_nonces` assign\n> and also available in  the `after_opening_head_tag` component.\n>\n> You should use those when including scripts or styles like this:\n>\n> ```heex\n>  ... \n>   \n>  ... \n>  \n> ```\n>\n> This ensures that your custom page can be used when a CSP is in place using the mechanism\n> supported by Phoenix LiveDashboard.\n>\n> If your custom page needs a different CSP policy, for example due to inline styles set by scripts,\n> please consider documenting these requirements.","title":"Custom Hooks - Phoenix.LiveDashboard.PageBuilder","ref":"Phoenix.LiveDashboard.PageBuilder.html#module-custom-hooks"},{"type":"type","doc":"","title":"Phoenix.LiveDashboard.PageBuilder.capabilities/0","ref":"Phoenix.LiveDashboard.PageBuilder.html#t:capabilities/0"},{"type":"function","doc":"Card component.\n\nYou can see it in use the Home and OS Data pages.","title":"Phoenix.LiveDashboard.PageBuilder.card/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#card/1"},{"type":"function","doc":"* `title` (`:string`) - The title above the card. Defaults to `nil`.\n* `hint` (`:string`) - A textual hint to show close to the title. Defaults to `nil`.\n* `inner_title` (`:string`) - The title inside the card. Defaults to `nil`.\n* `inner_hint` (`:string`) - A textual hint to show close to the inner title. Defaults to `nil`.\n* `dom_id` (`:string`) - id attribute for the HTML the main tag. Defaults to `nil`.","title":"Attributes - Phoenix.LiveDashboard.PageBuilder.card/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#card/1-attributes"},{"type":"function","doc":"* `inner_block` (required) - The value that the card will show.","title":"Slots - Phoenix.LiveDashboard.PageBuilder.card/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#card/1-slots"},{"type":"function","doc":"Card title component.","title":"Phoenix.LiveDashboard.PageBuilder.card_title/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#card_title/1"},{"type":"function","doc":"* `title` (`:string`) - The title above the card. Defaults to `nil`.\n* `hint` (`:string`) - A textual hint to show close to the title. Defaults to `nil`.","title":"Attributes - Phoenix.LiveDashboard.PageBuilder.card_title/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#card_title/1-attributes"},{"type":"function","doc":"Encodes an application for URLs.","title":"Phoenix.LiveDashboard.PageBuilder.encode_app/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#encode_app/1"},{"type":"function","doc":"This function can be used to encode an application for an event value:\n\n     />","title":"Example - Phoenix.LiveDashboard.PageBuilder.encode_app/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#encode_app/1-example"},{"type":"function","doc":"Encodes ETSs references for URLs.","title":"Phoenix.LiveDashboard.PageBuilder.encode_ets/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#encode_ets/1"},{"type":"function","doc":"This function can be used to encode an ETS reference for an event value:\n\n     />","title":"Example - Phoenix.LiveDashboard.PageBuilder.encode_ets/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#encode_ets/1-example"},{"type":"function","doc":"Encodes PIDs for URLs.","title":"Phoenix.LiveDashboard.PageBuilder.encode_pid/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#encode_pid/1"},{"type":"function","doc":"This function can be used to encode a PID for an event value:\n\n     />","title":"Example - Phoenix.LiveDashboard.PageBuilder.encode_pid/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#encode_pid/1-example"},{"type":"function","doc":"Encodes Port for URLs.","title":"Phoenix.LiveDashboard.PageBuilder.encode_port/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#encode_port/1"},{"type":"function","doc":"This function can be used to encode a Port for an event value:\n\n     />","title":"Example - Phoenix.LiveDashboard.PageBuilder.encode_port/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#encode_port/1-example"},{"type":"function","doc":"Encodes Sockets for URLs.","title":"Phoenix.LiveDashboard.PageBuilder.encode_socket/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#encode_socket/1"},{"type":"function","doc":"This function can be used to encode `@socket` for an event value:\n\n     />","title":"Example - Phoenix.LiveDashboard.PageBuilder.encode_socket/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#encode_socket/1-example"},{"type":"function","doc":"Fields card component.\n\nYou can see it in use the Home page in the Environment section.","title":"Phoenix.LiveDashboard.PageBuilder.fields_card/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#fields_card/1"},{"type":"function","doc":"* `fields` (`:list`) (required) - A list of key-value elements that will be shown inside the card.\n* `title` (`:string`) - The title above the card. Defaults to `nil`.\n* `hint` (`:string`) - A textual hint to show close to the title. Defaults to `nil`.\n* `inner_title` (`:string`) - The title inside the card. Defaults to `nil`.\n* `inner_hint` (`:string`) - A textual hint to show close to the inner title. Defaults to `nil`.","title":"Attributes - Phoenix.LiveDashboard.PageBuilder.fields_card/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#fields_card/1-attributes"},{"type":"callback","doc":"Callback invoked when an event is called.\n\nNote that `show_info` event is handled automatically by\n`Phoenix.LiveDashboard.PageBuilder`,\nbut the `info` parameter (`phx-value-info`) needs to be encoded with\none of the `encode_*` helper functions.\n\nFor more details, see [`Phoenix.LiveView bindings`](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html#module-bindings)","title":"Phoenix.LiveDashboard.PageBuilder.handle_event/3","ref":"Phoenix.LiveDashboard.PageBuilder.html#c:handle_event/3"},{"type":"callback","doc":"","title":"Phoenix.LiveDashboard.PageBuilder.handle_info/2","ref":"Phoenix.LiveDashboard.PageBuilder.html#c:handle_info/2"},{"type":"callback","doc":"","title":"Phoenix.LiveDashboard.PageBuilder.handle_params/3","ref":"Phoenix.LiveDashboard.PageBuilder.html#c:handle_params/3"},{"type":"callback","doc":"Callback invoked when the automatic refresh is enabled.","title":"Phoenix.LiveDashboard.PageBuilder.handle_refresh/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#c:handle_refresh/1"},{"type":"function","doc":"Hint pop-up text component","title":"Phoenix.LiveDashboard.PageBuilder.hint/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#hint/1"},{"type":"function","doc":"* `text` (`:string`) (required) - Text to show in the hint.","title":"Attributes - Phoenix.LiveDashboard.PageBuilder.hint/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#hint/1-attributes"},{"type":"callback","doc":"Callback invoked when a page is declared in the router.\n\nIt receives the router options and it must return the\ntuple `{:ok, session, requirements}`.\n\nThe page session will be serialized to the client and\nreceived on `mount`.\n\nThe requirements is an optional keyword to detect the\nstate of the node.\n\nThe result of this detection will be passed as second\nargument in the `c:menu_link/2` callback.\nThe possible values are:\n\n  * `:applications` list of applications that are running or not.\n  * `:modules` list of modules that are loaded or not.\n  * `:pids` list of processes that alive or not.","title":"Phoenix.LiveDashboard.PageBuilder.init/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#c:init/1"},{"type":"function","doc":"List of label value.\n\nYou can see it in use in the modal in Ports or Processes page.","title":"Phoenix.LiveDashboard.PageBuilder.label_value_list/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#label_value_list/1"},{"type":"function","doc":"* `elem` (required) - Value for each element of the list. Accepts attributes:\n\n  * `label` (`:string`) (required) - Label for the elem.","title":"Slots - Phoenix.LiveDashboard.PageBuilder.label_value_list/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#label_value_list/1-slots"},{"type":"function","doc":"Computes a router path to the current page.","title":"Phoenix.LiveDashboard.PageBuilder.live_dashboard_path/2","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_dashboard_path/2"},{"type":"function","doc":"Computes a router path to the current page with merged params.","title":"Phoenix.LiveDashboard.PageBuilder.live_dashboard_path/3","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_dashboard_path/3"},{"type":"function","doc":"A component for drawing layered graphs.\n\nThis is useful to represent pipelines like we have on\n[BroadwayDashboard](https://hexdocs.pm/broadway_dashboard) where\neach layer points to nodes of the layer below.\nIt draws the layers from top to bottom.\n\nThe calculation of layers and positions is done automatically\nbased on options.","title":"Phoenix.LiveDashboard.PageBuilder.live_layered_graph/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_layered_graph/1"},{"type":"function","doc":"* `id` (`:any`) (required) - Because is a stateful `Phoenix.LiveComponent` an unique id is needed.\n* `title` (`:string`) - The title of the component. Defaults to `nil`.\n* `hint` (`:string`) - A textual hint to show close to the title. Defaults to `nil`.\n* `layers` (`:list`) (required) - A graph of layers with nodes. They represent\n  our graph structure (see example). Each layer is a list\n  of nodes, where each node has the following fields:\n\n    - `:id` - The ID of the given node.\n    - `:children` - The IDs of children nodes.\n    - `:data` - A string or a map. If it's a map, the required fields\n      are `detail` and `label`.\n\n* `show_grid?` (`:boolean`) - Enable or disable the display of a grid. This is useful for development. Defaults to `false`.\n* `y_label_offset` (`:integer`) - The \"y\" offset of label position relative to the center of its circle. Defaults to `5`.\n* `y_detail_offset` (`:integer`) - The \"y\" offset of detail position relative to the center of its circle. Defaults to `18`.\n* `background` (`:any`) - A function that calculates the background for a\n  node based on it's data. Default: `fn _node_data -> \"gray\" end`.\"\n\n* `format_label` (`:any`) - A function that formats the label. Defaults\n  to a function that returns the label or data if data is binary.\n\n* `format_detail` (`:any`) - A function that formats the detail field.\n  This is only going to be called if data is a map.\n  Default: `fn node_data -> node_data.detail end`.","title":"Attributes - Phoenix.LiveDashboard.PageBuilder.live_layered_graph/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_layered_graph/1-attributes"},{"type":"function","doc":"iex> layers = [\n    ...>   [\n    ...>     %{\n    ...>       id: \"a1\",\n    ...>       data: \"a1\",\n    ...>       children: [\"b1\"]\n    ...>     }\n    ...>   ],\n    ...>   [\n    ...>     %{\n    ...>       id: \"b1\"\n    ...>       data: %{\n    ...>         detail: 0,\n    ...>         label: \"b1\"\n    ...>       },\n    ...>       children: []\n    ...>      }\n    ...>    ]\n    ...> ]","title":"Examples - Phoenix.LiveDashboard.PageBuilder.live_layered_graph/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_layered_graph/1-examples"},{"type":"function","doc":"Nav bar live component.\n\nYou can see it in use the Metrics and Ecto info pages.","title":"Phoenix.LiveDashboard.PageBuilder.live_nav_bar/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_nav_bar/1"},{"type":"function","doc":"* `id` (`:any`) (required) - Because is a stateful `Phoenix.LiveComponent` an unique id is needed.\n* `page` (`Phoenix.LiveDashboard.PageBuilder`) (required) - Dashboard page.\n* `nav_param` (`:string`) - An atom that configures the navigation parameter.\n  It is useful when two nav bars are present in the same page.\n\n  Defaults to `\"nav\"`.\n* `extra_params` (`:list`) - A list of strings representing the parameters\n  that should stay when a tab is clicked. By default the nav ignores\n  all params, except the current node if any.\n\n  Defaults to `[]`.\n* `style` (`:atom`) - Style for the nav bar.Must be one of `:pills`, or `:bar`.","title":"Attributes - Phoenix.LiveDashboard.PageBuilder.live_nav_bar/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_nav_bar/1-attributes"},{"type":"function","doc":"* `item` (required) - HTML to be rendered when the tab is selected. Accepts attributes:\n\n  * `name` (`:string`) (required) - Value used in the URL when the tab is selected.\n  * `label` (`:string`) - Title of the tab. If it is not present, it will be calculated from `name`.\n  * `method` (`:string`) - Method used to update.Must be one of `\"patch\"`, `\"navigate\"`, `\"href\"`, or `\"redirect\"`.","title":"Slots - Phoenix.LiveDashboard.PageBuilder.live_nav_bar/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_nav_bar/1-slots"},{"type":"function","doc":"Table live component.\n\nYou can see it in use the applications, processes, sockets pages and many others.","title":"Phoenix.LiveDashboard.PageBuilder.live_table/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_table/1"},{"type":"function","doc":"* `id` (`:any`) (required) - Because is a stateful `Phoenix.LiveComponent` an unique id is needed.\n* `page` (`Phoenix.LiveDashboard.PageBuilder`) (required) - Dashboard page.\n* `row_fetcher` (`:any`) (required) - A function which receives the params and the node and\n  returns a tuple with the rows and the total number:\n  `(params(), node() -> {list(), integer() | binary()})`.\n  Optionally, if the function needs to keep a state, it can be defined as a tuple\n  where the first element is a function and the second is the initial state.\n  In this case, the function will receive the state as third argument and must return\n  a tuple with the rows, the total number, and the new state for the following call:\n  `{(params(), node(), term() -> {list(), integer() | binary(), term()}), term()}`\n\n* `rows_name` (`:string`) - A string to name the representation of the rows. Default is calculated from the current page.\n* `row_attrs` (`:any`) - A list with the HTML attributes for the table row.\n  It can be also a function that receive the row as argument\n  and returns a list of 2 element tuple with HTML attribute name\n  and value.\n\n  Defaults to `nil`.\n* `default_sort_by` (`:any`) - The default column to sort by to. Defaults to the first sortable column. Defaults to `nil`.\n* `title` (`:string`) (required) - The title of the table.\n* `limit` (`:any`) - May be set to `false` to disable the `limit`. Defaults to `[50, 100, 500, 1000, 5000]`.\n* `search` (`:boolean`) - A boolean indicating if the search functionality is enabled. Defaults to `true`.\n* `hint` (`:string`) - A textual hint to show close to the title. Defaults to `nil`.\n* `dom_id` (`:string`) - id attribute for the HTML the main tag. Defaults to `nil`.","title":"Attributes - Phoenix.LiveDashboard.PageBuilder.live_table/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_table/1-attributes"},{"type":"function","doc":"* `col` (required) - Columns for the table. Accepts attributes:\n\n  * `field` (`:atom`) (required) - Identifier for the column.\n  * `sortable` (`:atom`) - When set, the column header is clickable and it fetches again rows with the new order.\n    Required for at least one column.\nMust be one of `:asc`, or `:desc`.\n  * `header` (`:string`) - Label to show in the current column. Default value is calculated from `:field`.\n  * `text_align` (`:string`) - Text align for text in the column. Default: `nil`.Must be one of `\"left\"`, `\"center\"`, `\"right\"`, or `\"justify\"`.","title":"Slots - Phoenix.LiveDashboard.PageBuilder.live_table/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#live_table/1-slots"},{"type":"callback","doc":"Callback invoked when a page is declared in the router.\n\nIt receives the session returned by the `c:init/1` callback\nand the capabilities of the current node.\n\nThe possible return values are:\n\n  * `{:ok, text}` when the link should be enable and text to be shown.\n\n  * `{:disabled, text}` when the link should be disable and text to be shown.\n\n  * `{:disabled, text, more_info_url}` similar to the previous one but\n    it also includes a link to provide more information to the user.\n\n  * `:skip` when the link should not be shown at all.","title":"Phoenix.LiveDashboard.PageBuilder.menu_link/2","ref":"Phoenix.LiveDashboard.PageBuilder.html#c:menu_link/2"},{"type":"callback","doc":"","title":"Phoenix.LiveDashboard.PageBuilder.mount/3","ref":"Phoenix.LiveDashboard.PageBuilder.html#c:mount/3"},{"type":"function","doc":"Registers a component to be rendered after the opening head tag in the layout.","title":"Phoenix.LiveDashboard.PageBuilder.register_after_opening_head_tag/2","ref":"Phoenix.LiveDashboard.PageBuilder.html#register_after_opening_head_tag/2"},{"type":"function","doc":"Registers a component to be rendered before the closing head tag in the layout.","title":"Phoenix.LiveDashboard.PageBuilder.register_before_closing_head_tag/2","ref":"Phoenix.LiveDashboard.PageBuilder.html#register_before_closing_head_tag/2"},{"type":"callback","doc":"","title":"Phoenix.LiveDashboard.PageBuilder.render/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#c:render/1"},{"type":"type","doc":"","title":"Phoenix.LiveDashboard.PageBuilder.requirements/0","ref":"Phoenix.LiveDashboard.PageBuilder.html#t:requirements/0"},{"type":"function","doc":"Row component.\n\nYou can see it in use the Home page and OS Data pages.","title":"Phoenix.LiveDashboard.PageBuilder.row/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#row/1"},{"type":"function","doc":"* `col` (required) - A list of components. It can receive up to 3 components. Each element will be one column.","title":"Slots - Phoenix.LiveDashboard.PageBuilder.row/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#row/1-slots"},{"type":"type","doc":"","title":"Phoenix.LiveDashboard.PageBuilder.session/0","ref":"Phoenix.LiveDashboard.PageBuilder.html#t:session/0"},{"type":"function","doc":"Shared usage card component.\n\nYou can see it in use the Home page and OS Data pages.","title":"Phoenix.LiveDashboard.PageBuilder.shared_usage_card/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#shared_usage_card/1"},{"type":"function","doc":"* `usages` (`:list`) (required) - A list of `Map` with the following keys:\n    * `:data` - A list of tuples with 4 elements with the following data: `{usage_name, usage_percent, color, hint}`\n    * `:dom_id` - Required. Usage identifier.\n    * `:title`- Bar title.\n\n* `total_data` (`:any`) (required) - A list of tuples with 4 elements with following data: `{usage_name, usage_value, color, hint}`.\n* `total_legend` (`:string`) (required) - The legent of the total usage.\n* `total_usage` (`:string`) (required) - The value of the total usage.\n* `dom_id` (`:string`) - id attribute for the HTML the main tag. Defaults to `nil`.\n* `csp_nonces` (`:any`) (required) - A copy of CSP nonces (`@csp_nonces`) used to render the page safely.\n* `title` (`:string`) - The title above the card. Defaults to `nil`.\n* `hint` (`:string`) - A textual hint to show close to the title. Defaults to `nil`.\n* `inner_title` (`:string`) - The title inside the card. Defaults to `nil`.\n* `inner_hint` (`:string`) - A textual hint to show close to the inner title. Defaults to `nil`.\n* `total_formatter` (`:any`) - A function that format the `total_usage`. Default: `&(\"#{&1} %\")`. Defaults to `nil`.","title":"Attributes - Phoenix.LiveDashboard.PageBuilder.shared_usage_card/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#shared_usage_card/1-attributes"},{"type":"type","doc":"","title":"Phoenix.LiveDashboard.PageBuilder.unsigned_params/0","ref":"Phoenix.LiveDashboard.PageBuilder.html#t:unsigned_params/0"},{"type":"function","doc":"Usage card component.\n\nYou can see it in use the Home page and OS Data pages.","title":"Phoenix.LiveDashboard.PageBuilder.usage_card/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#usage_card/1"},{"type":"function","doc":"* `title` (`:string`) - The title above the card. Defaults to `nil`.\n* `hint` (`:string`) - A textual hint to show close to the title. Defaults to `nil`.\n* `dom_id` (`:string`) (required) - A unique identifier for all usages in this card.\n* `csp_nonces` (`:any`) (required) - A copy of CSP nonces (`@csp_nonces`) used to render the page safely.","title":"Attributes - Phoenix.LiveDashboard.PageBuilder.usage_card/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#usage_card/1-attributes"},{"type":"function","doc":"* `usage` (required) - List of usages to show. Accepts attributes:\n\n  * `current` (`:integer`) (required) - The current value of the usage.\n  * `limit` (`:integer`) (required) - The max value of usage.\n  * `dom_id` (`:string`) (required) - An unique identifier for the usage that will be concatenated to `dom_id`.\n  * `percent` (`:string`) - The used percent of the usage.\n  * `title` (`:string`) - The title of the usage.\n  * `hint` (`:string`) - A textual hint to show close to the usage title.","title":"Slots - Phoenix.LiveDashboard.PageBuilder.usage_card/1","ref":"Phoenix.LiveDashboard.PageBuilder.html#usage_card/1-slots"},{"type":"module","doc":"A plug that enables request logging.\n\nSee [our Request Logger guides](request_logger.html) for more information.","title":"Phoenix.LiveDashboard.RequestLogger","ref":"Phoenix.LiveDashboard.RequestLogger.html"},{"type":"module","doc":"Provides LiveView routing for LiveDashboard.","title":"Phoenix.LiveDashboard.Router","ref":"Phoenix.LiveDashboard.Router.html"},{"type":"macro","doc":"Defines a LiveDashboard route.\n\nIt expects the `path` the dashboard will be mounted at\nand a set of options. You can then link to the route directly:\n\n     Dashboard","title":"Phoenix.LiveDashboard.Router.live_dashboard/2","ref":"Phoenix.LiveDashboard.Router.html#live_dashboard/2"},{"type":"macro","doc":"* `:live_socket_path` - Configures the socket path. it must match\n    the `socket \"/live\", Phoenix.LiveView.Socket` in your endpoint.\n\n  * `:csp_nonce_assign_key` - an assign key to find the CSP nonce\n    value used for assets. Supports either `atom()` or a map of\n    type `%{optional(:img) => atom(), optional(:script) => atom(), optional(:style) => atom()}`\n\n  * `:ecto_repos` - the repositories to show database information.\n    Currently only PostgreSQL, MySQL, and SQLite databases are supported.\n    If you don't specify but your app is running Ecto, we will try to\n    auto-discover the available repositories. You can disable this behavior\n    by setting `[]` to this option.\n\n  * `:env_keys` - Configures environment variables to display.\n    It is defined as a list of string keys. If not set, the environment\n    information will not be displayed\n\n  * `:home_app` - A tuple with the app name and version to show on\n    the home page. Defaults to `{\"Dashboard\", :phoenix_live_dashboard}`\n\n  * `:metrics` - Configures the module to retrieve metrics from.\n    It can be a `module` or a `{module, function}`. If nothing is\n    given, the metrics functionality will be disabled. If `false` is\n    passed, then the menu item won't be visible.\n\n  * `:metrics_history` - Configures a callback for retrieving metric history.\n    It must be an \"MFA\" tuple of  `{Module, :function, arguments}` such as\n      metrics_history: {MyStorage, :metrics_history, []}\n    If not set, metrics will start out empty/blank and only display\n    data that occurs while the browser page is open.\n\n  * `:on_mount` - Declares a custom list of `Phoenix.LiveView.on_mount/1`\n    callbacks to add to the dashboard's `Phoenix.LiveView.Router.live_session/3`.\n    A single value may also be declared.\n\n  * `:request_logger` - By default the Request Logger page is enabled. Passing\n     `false` will disable this page.\n\n  * `:request_logger_cookie_domain` - Configures the domain the request_logger\n    cookie will be written to. It can be a string or `:parent` atom.\n    When a string is given, it will directly  set cookie domain to the given\n    value. When `:parent` is given, it will take the parent domain from current\n    endpoint host (if host is \"www.acme.com\" the cookie will be scoped on\n    \"acme.com\"). When not set, the cookie will be scoped to current domain.\n\n  * `:allow_destructive_actions` - When true, allow destructive actions directly\n    from the UI. Defaults to `false`. The following destructive actions are\n    available in the dashboard:\n\n      * \"Kill process\" - a \"Kill process\" button on the process modal\n\n    Note that custom pages given to \"Additional pages\" may support their own\n    destructive actions.\n\n  * `:additional_pages` - A keyword list of additional pages","title":"Options - Phoenix.LiveDashboard.Router.live_dashboard/2","ref":"Phoenix.LiveDashboard.Router.html#live_dashboard/2-options"},{"type":"macro","doc":"defmodule MyAppWeb.Router do\n      use Phoenix.Router\n      import Phoenix.LiveDashboard.Router\n\n      scope \"/\", MyAppWeb do\n        pipe_through [:browser]\n        live_dashboard \"/dashboard\",\n          metrics: {MyAppWeb.Telemetry, :metrics},\n          env_keys: [\"APP_USER\", \"VERSION\"],\n          metrics_history: {MyStorage, :metrics_history, []},\n          request_logger_cookie_domain: \".acme.com\"\n      end\n    end","title":"Examples - Phoenix.LiveDashboard.Router.live_dashboard/2","ref":"Phoenix.LiveDashboard.Router.html#live_dashboard/2-examples"},{"type":"extras","doc":"# Configuring Ecto repository stats\n\nThis guide covers how to configure the LiveDashboard to show stats from your underlying database. At the moment, these stats can only be shown for Ecto repositories running on `Ecto.Adapters.Postgres` or `Ecto.Adapters.MyXQL`.","title":"Configuring Ecto repository stats","ref":"ecto_stats.html"},{"type":"extras","doc":"","title":"Installing Ecto Stats - Configuring Ecto repository stats","ref":"ecto_stats.html#installing-ecto-stats"},{"type":"extras","doc":"To enable the \"Ecto Stats\" functionality for PostgreSQL in your dashboard, you will need to do the three steps below:\n\n  1. Add the [`ecto_psql_extras`](https://hexdocs.pm/ecto_psql_extras) dependency\n  2. (optional) Configure the dashboard\n  3. (optional) Install custom PostgreSQL extensions\n\n#### Add the `ecto_psql_extras` dependency\n\nIn your `mix.exs`, add the following to your `deps`:\n\n```elixir\n  {:ecto_psql_extras, \"~> 0.6\"},\n```","title":"PostgreSQL - Configuring Ecto repository stats","ref":"ecto_stats.html#postgresql"},{"type":"extras","doc":"To enable the \"Ecto Stats\" functionality for MySQL or MariaDB in your dashboard, you will need to do the three steps below:\n\n  1. Add the [`ecto_mysql_extras`](https://hexdocs.pm/ecto_mysql_extras) dependency\n  2. (optional) Configure the dashboard\n  3. (optional) MySQL/MariaDB configuration\n\n#### Add the `ecto_mysql_extras` dependency\n\nIn your `mix.exs`, add the following to your `deps`:\n\n```elixir\n  {:ecto_mysql_extras, \"~> 0.3\"},\n```","title":"MySQL/MariaDB - Configuring Ecto repository stats","ref":"ecto_stats.html#mysql-mariadb"},{"type":"extras","doc":"To enable the \"Ecto Stats\" functionality for SQLite in your dashboard, you will need to do the three steps below:\n\n  1. Add the [`ecto_sqlite3_extras`](https://hexdocs.pm/ecto_sqlite3_extras) dependency\n  2. (optional) Configure the dashboard\n\n#### Add the `ecto_sqlite3_extras` dependency\n\nIn your `mix.exs`, add the following to your `deps`:\n\n```elixir\n  {:ecto_sqlite3_extras, \"~> 1.2.0\"},\n```","title":"SQLite - Configuring Ecto repository stats","ref":"ecto_stats.html#sqlite"},{"type":"extras","doc":"This step is **only needed if you want to restrict the repositories** listed in your dashboard, because\nby default all _repos_ are gonna be listed.\n\nGo to the `live_dashboard` call in your router and list your repositories:\n\n```elixir\nlive_dashboard \"/dashboard\", ecto_repos: [MyApp.Repo]\n```\n\nYou want to list all repositories that connect to distinct databases. For example, if you have both `MyApp.Repo` and `MyApp.RepoAnother` but they connect to the same database, there is no benefit in listing both. Remember only Ecto repositories running on `Ecto.Adapters.Postgres` or `Ecto.Adapters.MyXQL` are currently supported.\n\nIf you want to disable the \"Ecto Stats\" option altogether, set `ecto_repos: []`.\n\nSome queries such as `long_running_queries` can be configured by passing an extra `ecto_psql_extras_options` for PostgreSQL or `ecto_mysql_extras_options` for MySQL/MariaDB,\nwhich is a keyword where:\n\n- each key is the name of the query\n- each value is itself a keyword to be passed as `args`\n\nFor example, if you want to configure the threshold for `long_running_queries`:\n\n#### PostgreSQL example\n\n```elixir\nlive_dashboard \"/dashboard\",\n  ecto_repos: [MyApp.Repo],\n  ecto_psql_extras_options: [long_running_queries: [threshold: \"200 milliseconds\"]]\n```\n\nSee the [`ecto_psql_extras` documentation](https://hexdocs.pm/ecto_psql_extras/readme.html#usage) for available options.\n\n#### MySQL/MariaDB example\n\n```elixir\nlive_dashboard \"/dashboard\",\n  ecto_repos: [MyApp.Repo],\n  ecto_mysql_extras_options: [long_running_queries: [threshold: 200]]\n```\n\nSee the [`ecto_mysql_extras` documentation](https://hexdocs.pm/ecto_mysql_extras/readme.html#usage) for available options.\n\n#### SQLite example\n\n```elixir\nlive_dashboard \"/dashboard\",\n  ecto_repos: [MyApp.Repo],\n  ecto_sqlite3_extras_options: []\n```\n\nSee the [`ecto_sqlite3_extras` documentation](https://github.com/orsinium-labs/ecto_sqlite3_extras) for available options.","title":"Configure the dashboard - Configuring Ecto repository stats","ref":"ecto_stats.html#configure-the-dashboard"},{"type":"extras","doc":"Once the repository page is enabled, some of the queries (Calls and Outliers) require the [pg_stat_statements](https://www.postgresql.org/docs/current/pgstatstatements.html) extension to be installed. If you wish to access said functionality, you must install the extension first, otherwise said functionality won't be shown.","title":"Install custom PostgreSQL extensions - Configuring Ecto repository stats","ref":"ecto_stats.html#install-custom-postgresql-extensions"},{"type":"extras","doc":"The user which is accessing the repo should have access to the certain system level databases. See the [`ecto_mysql_extras` documentation](https://hexdocs.pm/ecto_mysql_extras/readme.html#mysql-mariadb-configuration) for more details which schemas are being used.\n\nFor MariaDB the `performance_schema` isn't enabled by default. To enable this add `performance_schema=ON` to `my.cnf`. These changes take effect after a restart. See the [`ecto_mysql_extras` documentation](https://hexdocs.pm/ecto_mysql_extras/readme.html#performance-schema) for more details.","title":"MySQL/MariaDB configuration - Configuring Ecto repository stats","ref":"ecto_stats.html#mysql-mariadb-configuration"},{"type":"extras","doc":"# Configuring metrics\n\nThis guide covers how to install and configure your LiveDashboard Metrics.","title":"Configuring metrics","ref":"metrics.html"},{"type":"extras","doc":"To enable the \"Metrics\" functionality in your dashboard, you will need to do the three steps below:\n\n  1. Add the telemetry dependencies\n  2. Define your telemetry module\n  3. Configure the dashboard","title":"Installing metrics - Configuring metrics","ref":"metrics.html#installing-metrics"},{"type":"extras","doc":"In your `mix.exs`, add the following to your `deps`:\n\n```elixir\n  {:telemetry_poller, \"~> 0.4\"},\n  {:telemetry_metrics, \"~> 0.4\"},\n```\n\nIf you generated your Phoenix app in version v1.5+, these dependencies will already be installed. You can also skip the next section.","title":"Add the telemetry dependencies - Configuring metrics","ref":"metrics.html#add-the-telemetry-dependencies"},{"type":"extras","doc":"In your Phoenix application, we recommend that you create a module to act as your telemetry supervision tree. Within this supervisor you can define your application's metrics and start your reporters.\n\nThe example below contains the child spec for a LiveDashboard reporter, as well as some metrics definitions for telemetry events emitted by Phoenix, Ecto, and the VM (via the `:telemetry_poller` package).\n\nCreate your Telemetry module in `lib/my_app_web/telemetry.ex`:\n\n```elixir\ndefmodule MyAppWeb.Telemetry do\n  use Supervisor\n  import Telemetry.Metrics\n\n  def start_link(arg) do\n    Supervisor.start_link(__MODULE__, arg, name: __MODULE__)\n  end\n\n  @impl true\n  def init(_arg) do\n    children = [\n      # Telemetry poller will execute the given period measurements\n      # every 10_000ms. Learn more here: https://hexdocs.pm/telemetry_metrics\n      {:telemetry_poller, measurements: periodic_measurements(), period: 10_000}\n      # Add reporters as children of your supervision tree.\n      # {Telemetry.Metrics.ConsoleReporter, metrics: metrics()}\n    ]\n\n    Supervisor.init(children, strategy: :one_for_one)\n  end\n\n  def metrics do\n    [\n      # Phoenix Metrics\n      summary(\"phoenix.endpoint.stop.duration\",\n        unit: {:native, :millisecond}\n      ),\n      summary(\"phoenix.router_dispatch.stop.duration\",\n        tags: [:route],\n        unit: {:native, :millisecond}\n      ),\n\n      # Database Time Metrics\n      summary(\"my_app.repo.query.total_time\", unit: {:native, :millisecond}),\n      summary(\"my_app.repo.query.decode_time\", unit: {:native, :millisecond}),\n      summary(\"my_app.repo.query.query_time\", unit: {:native, :millisecond}),\n      summary(\"my_app.repo.query.queue_time\", unit: {:native, :millisecond}),\n      summary(\"my_app.repo.query.idle_time\", unit: {:native, :millisecond}),\n\n      # VM Metrics\n      summary(\"vm.memory.total\", unit: {:byte, :kilobyte}),\n      summary(\"vm.total_run_queue_lengths.total\"),\n      summary(\"vm.total_run_queue_lengths.cpu\"),\n      summary(\"vm.total_run_queue_lengths.io\")\n    ]\n  end\n\n  defp periodic_measurements do\n    []\n  end\nend\n```\n\nMake sure to replace `MyApp` and `my_app` by your actual application name.\n\nThen add to your main application's supervision tree (usually in `lib/my_app/application.ex`):\n\n```elixir\nchildren = [\n  MyApp.Repo,\n  MyAppWeb.Telemetry,\n  MyAppWeb.Endpoint,\n  ...\n]\n```","title":"Define your telemetry module - Configuring metrics","ref":"metrics.html#define-your-telemetry-module"},{"type":"extras","doc":"The last step now is to configure the dashboard. Go to the `live_dashboard` call in your router and add the following option:\n\n```elixir\nlive_dashboard \"/dashboard\", metrics: MyAppWeb.Telemetry\n```\n\nNow refresh the \"/dashboard\" page and the metrics functionality should be enabled. Each metric goes to a distinct group based on the metric name itself.","title":"Configure the dashboard - Configuring metrics","ref":"metrics.html#configure-the-dashboard"},{"type":"extras","doc":"Now that you have metrics up and running, you can begin exploring the rest of the telemetry ecosystem! Here are a few links to get you started:\n\n* The [`Telemetry.Metrics`](https://hexdocs.pm/telemetry_metrics)\n  module documentation contains more information on:\n  * Metric types\n  * Breaking down metrics by tags\n  * VM Metrics\n  * Custom periodic polling\n\n* For a deeper dive into Phoenix and Ecto metrics, see our\n  [Telemetry Walkthrough](https://hexdocs.pm/phoenix/telemetry.html).\n\n* For more Elixir libraries using `:telemetry`, see\n  [Libraries using Telemetry](https://hexdocs.pm/phoenix/telemetry.html#libraries-using-telemetry).","title":"More about telemetry - Configuring metrics","ref":"metrics.html#more-about-telemetry"},{"type":"extras","doc":"The LiveDashboard integrates with `:telemetry` converting each  `Telemetry.Metrics` to a beautiful, real-time chart.\n\nThe following table shows how `Telemetry.Metrics` metrics map to LiveDashboard charts:\n\n| Telemetry.Metrics | Y-Axis Value(s)                                            |\n|-------------------|----------------------------------------------------------- |\n| `last_value`      | Always set to an absolute value                            |\n| `counter`         | Always increased by 1                                      |\n| `sum`             | Always increased/decreased by an absolute value            |\n| `summary`         | Value/Min/Max/Avg                                          |\n| `distribution`    | Total number of events in individual buckets               |","title":"Configure Metrics - Configuring metrics","ref":"metrics.html#configure-metrics"},{"type":"extras","doc":"Reporter options can be given to each metric as an option. For example:\n\n    counter(\"my_app.counter\", reporter_options: [...])\n\nThe following reporter options are available to the dashboard:\n\n  * `:nav` - configures the group the metric belongs to. By default the group is the first part of the name. For example, `counter(\"my_app.counter\")` defaults to group \"my_app\"\n\n  * `:prune_threshold` - the maximum number of data\n    points. When the threshold is reached, the chart data will\n    be pruned by half. Default is `1_000`.\n\n  * `:bucket_size` - the unit width of each bucket. This option only\n    applies to `distribution` histograms. The default value is `20`.","title":"Reporter options - Configuring metrics","ref":"metrics.html#reporter-options"},{"type":"extras","doc":"[Metrics history can also be enabled via a custom configuration](metrics_history.html).","title":"Metrics history - Configuring metrics","ref":"metrics.html#metrics-history"},{"type":"extras","doc":"# Configuring metrics history\n\nIf you wish to populate metrics with history saved from telemetry or another data source,\nmodify the dashboard config (in \"my_app_web/router.ex\") to include a `metrics_history` key like so:\n\n```elixir\nlive_dashboard \"/dashboard\",\n  metrics: MyAppWeb.Telemetry,\n  metrics_history: {MyApp.MetricsStorage, :metrics_history, []}\n```\n\nwhere `MetricsStorage` is a module and `:metrics_history` is a function taking a single argument in this example, which will always be a metric.\n\nThe function must return a list, empty if there is no data, or a list of maps with `:label`, `:measurement` and `:time` keys in every map. The function `Phoenix.LiveDashboard.extract_datapoint_for_metric/4` will return a map in exactly this format (with optional time argument if you want to override the default of `System.system_time(:microsecond)`), or it may return `nil` in which case the data point should not be saved.\n\nYou could store the data in an ETS table or in Redis or the database, or anywhere else, but for this example we'll use a GenServer, with a [circular buffer](https://en.wikipedia.org/wiki/Circular_buffer) to emit recent telemetry when each client connects.\n\nIn your `mix.exs`, add the following to your `deps`:\n\n```elixir\n  {:circular_buffer, \"~> 0.4.0\"},\n```\n\nThen add the following module \"lib/my_app_web/metrics_storage.ex\":\n\n```elixir\n  defmodule MyAppWeb.MetricsStorage do\n    use GenServer\n\n    @history_buffer_size 50\n\n    def metrics_history(metric) do\n      GenServer.call(__MODULE__, {:data, metric})\n    end\n\n    def start_link(args) do\n      GenServer.start_link(__MODULE__, args, name: __MODULE__)\n    end\n\n    @impl true\n    def init(metrics) do\n      Process.flag(:trap_exit, true)\n\n      metric_histories_map =\n        metrics\n        |> Enum.map(fn metric ->\n          attach_handler(metric)\n          {metric, CircularBuffer.new(@history_buffer_size)}\n        end)\n        |> Map.new()\n\n      {:ok, metric_histories_map}\n    end\n\n    @impl true\n    def terminate(_, metrics) do\n      for metric <- metrics do\n        :telemetry.detach({__MODULE__, metric, self()})\n      end\n\n      :ok\n    end\n\n    defp attach_handler(%{event_name: name_list} = metric) do\n      :telemetry.attach(\n        {__MODULE__, metric, self()},\n        name_list,\n        &__MODULE__.handle_event/4,\n        metric\n      )\n    end\n\n    def handle_event(_event_name, data, metadata, metric) do\n      if data = Phoenix.LiveDashboard.extract_datapoint_for_metric(metric, data, metadata) do\n        GenServer.cast(__MODULE__, {:telemetry_metric, data, metric})\n      end\n    end\n\n    @impl true\n    def handle_cast({:telemetry_metric, data, metric}, state) do\n      {:noreply, update_in(state[metric], &CircularBuffer.insert(&1, data))}\n    end\n\n    @impl true\n    def handle_call({:data, metric}, _from, state) do\n      if history = state[metric] do\n        {:reply, CircularBuffer.to_list(history), state}\n      else\n        {:reply, [], state}\n      end\n    end\n  end\n```\n\nFinally, add the new module to your Application children, and initialize it with some or all of your metrics, such as from `MyAppWeb.Telemetry.metrics/0`.\n\n```elixir\n  # Start genserver to store transient metrics\n  {MyAppWeb.MetricsStorage, MyAppWeb.Telemetry.metrics()},\n```\n\nNow, when you select a tab on the Metrics dashboard, LiveDashboard will call into your module to get the metrics history for that tab.","title":"Configuring metrics history","ref":"metrics_history.html"},{"type":"extras","doc":"# Configuring OS Data\n\nThis guide covers how to install and configure your LiveDashboard OS Data.","title":"Configuring OS Data","ref":"os_mon.html"},{"type":"extras","doc":"The OS Data comes from the `os_mon` application, which ships as part of your Erlang distribution. You can start it by adding it to the extra applications section in your `mix.exs`:\n\n```elixir\n  def application do\n    [\n      ...,\n      extra_applications: [:logger, :runtime_tools, :os_mon]\n    ]\n  end\n```\n\n> Some operating systems break Erlang into multiple packages. In this case, you may need to install a package such as `erlang-os-mon` or similar.","title":"Enabling `os_mon` - Configuring OS Data","ref":"os_mon.html#enabling-os_mon"},{"type":"extras","doc":"See [the Erlang docs](https://www.erlang.org/doc/apps/os_mon/os_mon_app.html) for more information and `os_mon` configuration.","title":"Configuring os_mon - Configuring OS Data","ref":"os_mon.html#configuring-os_mon"},{"type":"extras","doc":"# Configuring request logger\n\nThis guide covers how to install and configure your LiveDashboard request logger.","title":"Configuring request logger","ref":"request_logger.html"},{"type":"extras","doc":"Installing the request logger is straight-forward. Just add the following plug to your \"lib/my_app_web/endpoint.ex\", right before `Plug.RequestId`:\n\n```elixir\nplug Phoenix.LiveDashboard.RequestLogger,\n  param_key: \"request_logger\",\n  cookie_key: \"request_logger\"\n```\n\nIf your application is an API only, then you most likely don't use cookies, which means you can remove the \"cookie_key\" option.\n\nNow go to your dashboard and the Request Logger will be enabled. Once you click it, you will have the option to either pass a parameter to stream requests logs or to enable/disable a cookie that streams requests logs.","title":"Installing request logger - Configuring request logger","ref":"request_logger.html#installing-request-logger"},{"type":"extras","doc":"There is no configuration for the request logger at the moment.","title":"Configuring request logger - Configuring request logger","ref":"request_logger.html#configuring-request-logger"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}